import { LinearProgress } from "@mui/material";
import { RootPaper } from "@ess-ics/ce-ui-common";

import { IOCDetailsView } from "./IOCDetailsView";
import { NotFoundView } from "../../components/navigation/NotFoundView/NotFoundView";
import { useGetIocQuery } from "../../store/enhancedApi";
import { ApiAlertError } from "../../components/common/Alerts/ApiAlertError";

const IOC_POLL_INTERVAL = 5000;

interface IOCDetailsContainerProps {
  id?: string;
}

export function IOCDetailsContainer({ id }: IOCDetailsContainerProps) {
  const {
    data: ioc,
    isLoading,
    error
  } = useGetIocQuery(
    { iocId: Number(id) },
    { skip: !id, pollingInterval: IOC_POLL_INTERVAL }
  );

  if (error && "status" in error && error.status === 404) {
    return <NotFoundView />;
  }

  if (error) {
    return <ApiAlertError error={error} />;
  }

  if (isLoading || !ioc) {
    return (
      <RootPaper>
        <LinearProgress color="primary" />
      </RootPaper>
    );
  }

  return (
    <RootPaper>
      {ioc ? <IOCDetailsView ioc={ioc} /> : <LinearProgress color="primary" />}
    </RootPaper>
  );
}
